@@ -1,15 +1,17 @@
-import logging
 from pathlib import Path
 
 from PyQt5.QtCore import QEvent, QMimeData, Qt, pyqtSignal
 from PyQt5.QtGui import QDrag
 from PyQt5.QtWidgets import QApplication
 
+from gridplayer.models.video import filter_video_uris
 from gridplayer.player.managers.base import ManagerBase
-from gridplayer.utils.files import drag_get_files, drag_get_video_id, drag_has_video_id
-from gridplayer.video import Video
-
-logger = logging.getLogger(__name__)
+from gridplayer.utils.files import (
+    drag_get_uris,
+    drag_get_video,
+    drag_has_video,
+    get_playlist_path,
+)
 
 
 class DragNDropManager(ManagerBase):
@@ -46,7 +48,7 @@ class DragNDropManager(ManagerBase):
     def dragEnterEvent(self, event):
         drag_data = event.mimeData()
 
-        if not drag_get_files(drag_data) and not drag_has_video_id(drag_data):
+        if not drag_get_uris(drag_data) and not drag_has_video(drag_data):
             return
 
         event.setDropAction(Qt.MoveAction)
@@ -54,41 +56,58 @@ class DragNDropManager(ManagerBase):
 
     def dropEvent(self, event):
         drop_data = event.mimeData()
-        drop_files = drag_get_files(drop_data)
+        drop_files = drag_get_uris(drop_data)
+        drop_video = drag_get_video(drop_data)
 
         # Add new video
         if drop_files:
-            if drop_files[0].suffix == ".gpls":
-                self.playlist_dropped.emit(drop_files[0])
-            else:
-                videos = [Video(file_path=f, title=f.name) for f in drop_files]
-                self.videos_dropped.emit(videos)
+            return self._drop_files(event, drop_files)
 
-            event.acceptProposedAction()
+        # Swap videos or transfer from another instance
+        elif drop_video:
+            return self._drop_video_block(event, drop_video)
 
-            return True
+    def dragMoveEvent(self, event):
+        drag_video = drag_get_video(event.mimeData())
 
-        # Swap videos
-        elif drag_has_video_id(drop_data):
+        if drag_video:
+            src_video = self._ctx.video_blocks.by_id(drag_video.id)
+            if src_video:
+                src_video.show_overlay()
+
+    def _drop_files(self, event, drop_files):
+        playlist = get_playlist_path(drop_files)
+
+        if playlist:
+            self.playlist_dropped.emit(playlist)
+        else:
+            videos = filter_video_uris(drop_files)
+            self.videos_dropped.emit(videos)
+
+        event.acceptProposedAction()
+
+        return True
+
+    def _drop_video_block(self, event, dropped_video):
+        src_video = self._ctx.video_blocks.by_id(dropped_video.id)
+
+        # Local video, swapping
+        if src_video:
             dst_video = self._ctx.active_block
             if dst_video is None:
-                logger.debug("No video under cursor, discarding drop")
+                self._log.debug("No video under cursor, discarding drop")
                 return False
 
-            src_video = self._ctx.video_blocks.by_id(drag_get_video_id(drop_data))
-
             self._swap_videos(src_video, dst_video)
 
-            event.acceptProposedAction()
+        # Video from other player instance, adding as new
+        else:
+            self._log.debug("Dropped video from another instance")
+            self.videos_dropped.emit([dropped_video.video])
 
-            return True
+        event.acceptProposedAction()
 
-    def dragMoveEvent(self, event):
-        drop_data = event.mimeData()
-
-        if drag_has_video_id(drop_data):
-            src_video = self._ctx.video_blocks.by_id(drag_get_video_id(drop_data))
-            src_video.show_overlay()
+        return True
 
     def _is_drag_started(self, event):
         if not event.buttons() & Qt.LeftButton:
@@ -104,12 +123,17 @@ class DragNDropManager(ManagerBase):
         return self._ctx.active_block is not None
 
     def _get_drag_video(self):
+        if not self._ctx.active_block:
+            return None
+
+        drag_data = self._ctx.active_block.drag_data.json()
+
         drag = QDrag(self)
 
         mimeData = QMimeData()
         mimeData.setData(
-            "application/x-gridplayer-video-id",
-            self._ctx.active_block.id.encode(),
+            "application/x-gridplayer-video",
+            drag_data.encode("utf-8"),
         )
         drag.setMimeData(mimeData)
 
@@ -118,10 +142,10 @@ class DragNDropManager(ManagerBase):
         return drag
 
     def _swap_videos(self, src, dst):
-        logger.debug(f"Swapping {src.id} with {dst.id}")
+        self._log.debug(f"Swapping {src.id} with {dst.id}")
 
         if src == dst:
-            logger.debug("No video swap needed")
+            self._log.debug("No video swap needed")
             return
 
         self._ctx.video_blocks.swap(dst, src)
