@@ -4,7 +4,7 @@ from gridplayer.dialogs.messagebox import QCustomMessageBox
 from gridplayer.dialogs.settings import SettingsDialog
 from gridplayer.player.managers.base import ManagerBase
 from gridplayer.settings import Settings
-from gridplayer.utils.misc import tr
+from gridplayer.utils.qt import translate
 
 
 class SettingsManager(ManagerBase):
@@ -27,8 +27,11 @@ class SettingsManager(ManagerBase):
         if self._is_restart_needed(previous_settings):
             QCustomMessageBox.information(
                 self.parent(),
-                tr("Settings"),
-                tr("Restart is required for the new settings to take effect."),
+                translate("Dialog - Settings apply restart", "Settings", "Header"),
+                translate(
+                    "Dialog - Settings apply restart",
+                    "Restart is required for the new settings to take effect.",
+                ),
             )
 
         if self._is_reload_needed(previous_settings):
@@ -51,6 +54,8 @@ class SettingsManager(ManagerBase):
             "player/video_driver",
             "player/video_driver_players",
             "internal/opaque_hw_overlay",
+            "internal/fake_overlay_invisibility",
+            "misc/vlc_options",
         }
 
         return self._setting_changes(previous_settings, checks)
@@ -58,6 +63,9 @@ class SettingsManager(ManagerBase):
     def _is_restart_needed(self, previous_settings):
         checks = {
             "player/language",
+            "logging/log_limit",
+            "logging/log_limit_size",
+            "logging/log_limit_backups",
         }
 
         return self._setting_changes(previous_settings, checks)
